==> scanbot_sdk-2.9.0.tar.gz: lib/classical_components/finder.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:scanbot_sdk/classical_components/camera_configuration.dart';

class FinderView extends StatefulWidget {
  final FinderConfiguration config;
  final String? viewId;

  const FinderView({Key? key, required this.config, this.viewId})
      : super(key: key);

  @override
  State<FinderView> createState() => _FinderViewState(viewId);
}

class _FinderViewState extends State<FinderView> {
  late MethodChannel finderChannel;
  final String? viewId;
  double left = 0;
  double top = 0;
  double right = 0;
  double bottom = 0;

  _FinderViewState(this.viewId);

  @override
  void initState() {
    finderChannel = widget.viewId != null
        ? MethodChannel('scanbot_sdk_camera.finder_${widget.viewId}')
        : const MethodChannel('scanbot_sdk_camera.finder');
    finderChannel.setMethodCallHandler(_channelHandler);
    super.initState();
  }

  @override
  void dispose() {
    finderChannel.setMethodCallHandler(null);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (left == 0 && right == 0 && top == 0 && bottom == 0) {
      return Container();
    }
    return SizedBox(
        width: double.infinity,
        height: double.infinity,
        child: LayoutBuilder(
            builder: (BuildContext ctx, BoxConstraints constraints) {
          var Hp = constraints.maxHeight;
          var Wp = constraints.maxWidth;
          var shoulAddBottomContainer = Hp - bottom > 0;
          var shoulAddTopContainer = Hp - top > 0;
          return Stack(children: [
            ColorFiltered(
              colorFilter: ColorFilter.mode(
                  widget.config.backgroundColor ??
                      Colors.black.withOpacity(0.8),
                  BlendMode.srcOut),
              // This one will create the magic
              child: Stack(
                fit: StackFit.expand,
                children: [
                  Container(
                    decoration: const BoxDecoration(
                        color: Colors.black,
                        backgroundBlendMode: BlendMode
                            .dstOut), // This one will handle background + difference out
                  ),
                  Positioned(
                    left: max(left, 0),
                    top: max(top, 0),
                    right: max(Wp - right, 0),
                    bottom: max(Hp - bottom, 0),
                    child: SizedBox(
                      width: double.infinity,
                      height: double.infinity,
                      child: Stack(
                        children: [
                          Container(
                              decoration: widget.config.decoration
                                  .copyWith(color: Colors.black)),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ),
            Stack(
              children: [
                if (shoulAddTopContainer)
                  Align(
                      alignment: Alignment.topCenter,
                      child: SizedBox(
                          height: top,
                          width: double.infinity,
                          child: widget.config.topWidget ?? Container())),
                Positioned(
                  left: max(left, 0),
                  top: max(top, 0),
                  right: max(Wp - right, 0),
                  bottom: max(Hp - bottom, 0),
                  child: SizedBox(
                    width: double.infinity,
                    height: double.infinity,
                    child: Stack(
                      children: [
                        Container(decoration: widget.config.decoration),
                        widget.config.widget ?? Container()
                      ],
                    ),
                  ),
                ),
                if (shoulAddBottomContainer)
                  Align(
                      alignment: Alignment.bottomCenter,
                      child: SizedBox(
                          height: Hp - bottom,
                          width: double.infinity,
                          child: widget.config.bottomWidget ?? Container())),
              ],
            )
          ]);
        }));
  }

  Future<dynamic> _channelHandler(MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'finderSizeChanged':
        setState(() {
          left = methodCall.arguments["left"];
          top = methodCall.arguments["top"];
          right = methodCall.arguments["right"];
          bottom = methodCall.arguments["bottom"];
          widget.config.onFinderRectChange?.call(left, top, right, bottom);
        });
        break;
      default:
    }
    return;
  }
}

typedef OnFinderRectChange = Function(
    double left, double top, double right, double bottom);

==> scanbot_sdk-2.10.0.tar.gz: lib/classical_components/finder.dart <==
import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:scanbot_sdk/classical_components/camera_configuration.dart';

class FinderView extends StatefulWidget {
  final FinderConfiguration config;
  final String? viewId;

  const FinderView({Key? key, required this.config, this.viewId})
      : super(key: key);

  @override
  State<FinderView> createState() => _FinderViewState(viewId);
}

class _FinderViewState extends State<FinderView> {
  late MethodChannel finderChannel;
  final String? viewId;
  double left = 0;
  double top = 0;
  double right = 0;
  double bottom = 0;

  _FinderViewState(this.viewId);

  @override
  void initState() {
    finderChannel = widget.viewId != null
        ? MethodChannel('scanbot_sdk_camera.finder_${widget.viewId}')
        : const MethodChannel('scanbot_sdk_camera.finder');
    finderChannel.setMethodCallHandler(_channelHandler);
    left = widget.config.finderInsets?.left ?? 0;
    top = widget.config.finderInsets?.top ?? 0;
    right = widget.config.finderInsets?.right ?? 0;
    bottom = widget.config.finderInsets?.bottom ?? 0;
    super.initState();
  }

  @override
  void dispose() {
    finderChannel.setMethodCallHandler(null);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (left == 0 && right == 0 && top == 0 && bottom == 0) {
      return Container();
    }
    return SizedBox(
        width: double.infinity,
        height: double.infinity,
        child: LayoutBuilder(
            builder: (BuildContext ctx, BoxConstraints constraints) {
          var hp = constraints.maxHeight;
          var wp = constraints.maxWidth;
          var shoulAddBottomContainer = hp - bottom > 0;
          var shoulAddTopContainer = hp - top > 0;
          return Stack(children: [
            ColorFiltered(
              colorFilter: ColorFilter.mode(
                  widget.config.backgroundColor ??
                      Colors.black.withOpacity(0.8),
                  BlendMode.srcOut),
              // This one will create the magic
              child: Stack(
                fit: StackFit.expand,
                children: [
                  Container(
                    decoration: const BoxDecoration(
                        color: Colors.black,
                        backgroundBlendMode: BlendMode
                            .dstOut), // This one will handle background + difference out
                  ),
                  Positioned(
                    left: max(left, 0),
                    top: max(top, 0),
                    right: max(wp - right, 0),
                    bottom: max(hp - bottom, 0),
                    child: SizedBox(
                      width: double.infinity,
                      height: double.infinity,
                      child: Stack(
                        children: [
                          Container(
                              decoration: widget.config.decoration
                                  .copyWith(color: Colors.black)),
                        ],
                      ),
                    ),
                  ),
                ],
              ),
            ),
            Stack(
              children: [
                if (shoulAddTopContainer)
                  Align(
                      alignment: Alignment.topCenter,
                      child: SizedBox(
                          height: top,
                          width: double.infinity,
                          child: widget.config.topWidget ?? Container())),
                Positioned(
                  left: max(left, 0),
                  top: max(top, 0),
                  right: max(wp - right, 0),
                  bottom: max(hp - bottom, 0),
                  child: SizedBox(
                    width: double.infinity,
                    height: double.infinity,
                    child: Stack(
                      children: [
                        Container(decoration: widget.config.decoration),
                        widget.config.widget ?? Container()
                      ],
                    ),
                  ),
                ),
                if (shoulAddBottomContainer)
                  Align(
                      alignment: Alignment.bottomCenter,
                      child: SizedBox(
                          height: hp - bottom,
                          width: double.infinity,
                          child: widget.config.bottomWidget ?? Container())),
              ],
            )
          ]);
        }));
  }

  Future<dynamic> _channelHandler(MethodCall methodCall) async {
    switch (methodCall.method) {
      case 'finderSizeChanged':
        if (mounted) {
          setState(() {
            left = methodCall.arguments["left"];
            top = methodCall.arguments["top"];
            right = methodCall.arguments["right"];
            bottom = methodCall.arguments["bottom"];
            widget.config.onFinderRectChange?.call(left, top, right, bottom);
          });
        }
        break;
      default:
    }
    return;
  }
}

typedef OnFinderRectChange = Function(
    double left, double top, double right, double bottom);
